%global modname flask
%global srcname Flask

Name:           python3-%{modname}
Version:        1.1.4
Release:        1%{?dist}
Summary:        Micro-framework for Python based on Werkzeug, Jinja 2 and good intentions

License:        BSD
URL:            https://flask.palletsprojects.com
Source0:        %{pypi_source}

# CVE-2023-30861
# https://github.com/pallets/flask/security/advisories/GHSA-m2qf-hxjv-5gpq
# https://github.com/pallets/flask/commit/8646edca6f47e2cd57464081b3911218d4734f8d
Patch1:         0001-set-Vary-Cookie-header-consistently-for-session.patch

# downstream-only patch for compatibility with pytest 2.9.2 in EPEL 7
Patch2:         0002-Old-pytest-compatibility.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-pytest
BuildRequires:  python36-werkzeug >= 0.15
BuildRequires:  python36-jinja2 >= 2.10.1
BuildRequires:  python36-itsdangerous >= 0.24
BuildRequires:  python36-click >= 5.1

Requires:       python36-werkzeug >= 0.15
Requires:       python36-jinja2 >= 2.10.1
Requires:       python36-itsdangerous >= 0.24
Requires:       python36-click >= 5.1
Requires:       python3-setuptools

%{?python_provide:%python_provide python3-%{modname}}


%description
Flask is a lightweight WSGI web application framework.  It is designed to make
getting started quick and easy, with the ability to scale up to complex
applications.  It began as a simple wrapper around Werkzeug and Jinja and has
become one of the most popular Python web application frameworks.

Flask offers suggestions, but doesn't enforce any dependencies or project
layout.  It is up to the developer to choose the tools and libraries they want
to use.  There are many extensions provided by the community that make adding
new functionality easy.


%prep
%autosetup -n %{srcname}-%{version} -p 1
rm -rf src/%{srcname}.egg-info
rm -rf examples/flaskr/
rm -rf examples/minitwit/


%build
%py3_build


%install
%py3_install
mv %{buildroot}%{_bindir}/%{modname}{,-%{python3_version}}
ln -s %{modname}-%{python3_version} %{buildroot}%{_bindir}/%{modname}-3


%check
export LANG=en_US.UTF-8
export PYTHONPATH=%{buildroot}%{python3_sitelib}
py.test-%{python3_version} --verbose tests


%files
%license LICENSE.rst
%doc CHANGES.rst README.rst
%{_bindir}/%{modname}-3
%{_bindir}/%{modname}-%{python3_version}
%{python3_sitelib}/%{srcname}-*.egg-info/
%{python3_sitelib}/%{modname}/


%changelog
* Tue Aug 29 2023 Carl George <carlwgeorge@fedoraproject.org> - 1.1.4-1
- Update to version 1.1.4
- Rename python36-flask to python3-flask
- Backport patch for CVE-2023-30861, resolves rhbz#2196676
- Run test suite in %%check

* Wed Apr 08 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 1.1.2-4
- Add Requires for setuptools

* Wed Apr 08 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 1.1.2-3
- Drop unversioned binary

* Wed Apr 08 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 1.1.2-2
- Remove Obsoletes

* Wed Apr 08 2020 Igor Raits <ignatenkobrain@fedoraproject.org> - 1.1.2-1
- Initial import
